@@ -1,5 +1,5 @@
 package Form::Tiny::Form;
-$Form::Tiny::Form::VERSION = '2.16';
+$Form::Tiny::Form::VERSION = '2.17';
 use v5.10;
 use strict;
 use warnings;
@@ -306,15 +306,18 @@ See L<Form::Tiny::Manual>
 
 =head1 DESCRIPTION
 
-This role gets automatically mixed in by importing L<Form::Tiny> into your namespace.
+This role gets automatically mixed in by importing L<Form::Tiny> into your
+namespace.
 
 =head1 ADDED INTERFACE
 
-This section describes the interface added to your class after mixing in the Form::Tiny role.
+This section describes the interface added to your class after mixing in the
+Form::Tiny role.
 
 =head2 ATTRIBUTES
 
-Each of the attributes can be accessed by calling its name as a function on Form::Tiny object.
+Each of the attributes can be accessed by calling its name as a function on
+Form::Tiny object.
 
 =head3 input
 
@@ -324,29 +327,36 @@ B<writer:> I<set_input>
 
 =head3 fields
 
-Contains the validated and cleaned fields set after the validation is complete. Cannot be specified in the constructor.
+Contains the validated and cleaned fields set after the validation is complete.
+Cannot be specified in the constructor.
 
 =head3 field_defs
 
-Contains an array reference of L<Form::Tiny::FieldDefinition> instances fetched from the metaclass with context of current instance. Rebuilds everytime new input data is set.
+Contains an array reference of L<Form::Tiny::FieldDefinition> instances fetched
+from the metaclass with context of current instance. Rebuilds everytime new
+input data is set.
 
 =head3 errors
 
-Contains an array reference of form errors which were detected by the last performed validation. Each error is an instance of L<Form::Tiny::Error>.
+Contains an array reference of form errors which were detected by the last
+performed validation. Each error is an instance of L<Form::Tiny::Error>.
 
 B<predicate:> I<has_errors>
 
 =head2 METHODS
 
-This section describes standalone methods available in the module - they are not directly connected to any of the attributes.
+This section describes standalone methods available in the module - they are
+not directly connected to any of the attributes.
 
 =head3 new
 
-This is a Moose-flavored constructor for the class. It accepts a hash or hash reference of parameters, which are the attributes specified above.
+This is a Moose-flavored constructor for the class. It accepts a hash or hash
+reference of parameters, which are the attributes specified above.
 
 =head3 valid
 
-Performs the validation and returns a boolean which indicates whether the form is valid or not.
+Performs the validation and returns a boolean which indicates whether the form
+is valid or not.
 
 Accepts no arguments. Input must be set before calling this method.
 
@@ -354,11 +364,14 @@ Accepts no arguments. Input must be set before calling this method.
 
 =head3 validate
 
-These methods are here to ensure that a Form::Tiny instance can be used as a type validator itself by other form classes.
+These methods are here to ensure that a Form::Tiny instance can be used as a
+type validator itself by other form classes.
 
-I<check> returns a boolean value that indicates whether the validation of input data was successful.
+I<check> returns a boolean value that indicates whether the validation of input
+data was successful.
 
-I<validate> does the same thing, but instead of returning a boolean it returns a list of errors that were detected, or undef if none.
+I<validate> does the same thing, but instead of returning a boolean it returns
+a list of errors that were detected, or undef if none.
 
 Both methods take input data as the only argument.
 
@@ -371,19 +384,30 @@ Both methods take input data as the only argument.
 
 Can be used to interact with L</fields> hashref indirectly with key safety checks.
 
-After validation, this method returns form value of the given field. If the form was not yet validated or the validation was unsuccessful, returns C<undef>.
+After validation, this method returns form value of the given field. If the
+form was not yet validated or the validation was unsuccessful, returns
+C<undef>.
 
-Accepts a single argument: a field name. Will raise an exception if such field was not defined.
+Accepts a single argument: a field name. Will raise an exception if such field
+was not defined.
 
-If the field contains an array (C<*>) will return an array reference of all values for that field. Order of those values will be the same as in the input array(s).
+If the field contains an array (C<*>) will return an array reference of all
+values for that field. Order of those values will be the same as in the input
+array(s).
 
-I<Note:> currently, the field name passed must be a full field name (not a part of field name). For example, passing C<hash.hash> when the field is specified as C<hash.hash.field> will raise an exception. This may change in the future.
+I<Note:> currently, the field name passed must be a full field name (not a part
+of field name). For example, passing C<hash.hash> when the field is specified
+as C<hash.hash.field> will raise an exception. This may change in the future.
 
 =head3 errors_hash
 
-Helper method which returns errors much like the C<errors> form attribute, but in a hash reference with form field names as keys. Errors not assigned to any specific field end up in empty string key. The values are array references of error messages (strings).
+Helper method which returns errors much like the C<errors> form attribute, but
+in a hash reference with form field names as keys. Errors not assigned to any
+specific field end up in empty string key. The values are array references of
+error messages (strings).
 
-Each field will only be present in the hash if it has an error assigned to it. If no errors are present, the hash will be empty.
+Each field will only be present in the hash if it has an error assigned to it.
+If no errors are present, the hash will be empty.
 
 It allows you to get errors in format which is easier to navigate:
 
@@ -404,5 +428,6 @@ It allows you to get errors in format which is easier to navigate:
 	$form->add_error($field_name => $error_string);
 	$form->add_error($error_object);
 
-Adds an error to the form. If C<$error_object> style is used, it must be an instance of L<Form::Tiny::Error>.
+Adds an error to the form. If C<$error_object> style is used, it must be an
+instance of L<Form::Tiny::Error>.
 
